﻿using NMaxDashboard.Core.Models;
using System;
using System.Collections.ObjectModel;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TelerikChartRealTime
{
    public sealed partial class LiveDataView : UserControl
    {
        private readonly DispatcherTimer timer;
        private readonly Random rand;
        private readonly ObservableCollection<ChartPoint> data;

        public LiveDataView()
        {
            InitializeComponent();
            
            timer = new DispatcherTimer { Interval = TimeSpan.FromMilliseconds(250) };
            timer.Tick += OnTimerTick;

            rand = new Random();

            MySeries.ItemsSource = data = new ObservableCollection<ChartPoint>();
        }

        private void OnTimerTick(object sender, object e)
        {
            data.Add(new ChartPoint
            {
                Date = DateTime.Now.AddMilliseconds(-250), 
                Value = rand.Next(100, 200)
            });

            // if the data is older than 5 seconds (there are 4 data points added every second) remove the first data point
            // This is so that the chart looks like it is scrolling with real-time data (instead of squeezing it)
            if (data.Count > 20)
            {
                data.RemoveAt(0);
            }
        }

        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            if (timer.IsEnabled)
            {
                timer.Stop();
                (sender as Button).Content = "Start";
            }
            else
            {
                if(data.Count==0)
                   AddFirstData();

                timer.Start();
                (sender as Button).Content = "Stop";
            }
        }

        private void AddFirstData()
        {
            for(var i = 20; i > 0; i--)
            {
                var milliSecondsToSubtract = 250 * i;

                data.Add(new ChartPoint
                {
                    Date = DateTime.Now.AddMilliseconds(-milliSecondsToSubtract), 
                    Value = rand.Next(100, 200)
                });
            }
        }
    }
}
